@@ -1,10 +1,15 @@
 class ImageNotFoundErr(BaseException):
-    def __init__(self, *args: object):
+    def __init__(self, *args: object) -> None:
         super().__init__(*args)
 
 
 class NetworkErr(BaseException):
-    def __init__(self, *args: object):
+    def __init__(self, *args: object) -> None:
+        super().__init__(*args)
+
+
+class ShipNotFoundErr(BaseException):
+    def __init__(self, *args: object) -> None:
         super().__init__(*args)
 
 
@@ -15,10 +20,10 @@ class CriticalErr(BaseException):
         BaseException (_type_): _description_
     """
 
-    def __init__(self, *args: object):
+    def __init__(self, *args: object) -> None:
         super().__init__(*args)
 
 
 class LogitException(BaseException):
-    def __init__(self, *args: object):
+    def __init__(self, *args: object) -> None:
         super().__init__()(*args)
