@@ -35,13 +35,3 @@ TYPE_SCAN_AREA = [
         (322, 334, 354, 350),
     ],
 ]
-
-
-FIGHT_CONDITIONS_POSITION = [
-    None,
-    (207, 221),
-    (443, 287),
-    (752, 196),
-    (191, 413),
-    (733, 400),
-]
